@@ -1,7 +1,7 @@
+use compact_str::CompactStr;
 use itertools::Itertools;
 use reqwest::Error;
 use serde::de::DeserializeOwned;
-use smartstring::alias::String as SmartString;
 
 mod model;
 use model::FindResult;
@@ -19,6 +19,13 @@ pub struct Client {
 	language: String
 }
 
+fn compact_str_url(k: &str, v: &str) -> CompactStr {
+	let mut s = CompactStr::from(k);
+	s.push('=');
+	s.push_str(v);
+	s
+}
+
 impl Client {
 	pub fn new(api_key: String) -> Self {
 		Self::with_language(api_key, "en".into())
@@ -32,20 +39,20 @@ impl Client {
 		}
 	}
 	
-	async fn get<T: DeserializeOwned>(&self, path: &str, args: &[(&'static str, SmartString)]) -> Result<T, Error> {
+	async fn get<T: DeserializeOwned>(&self, path: &str, args: &[(&'static str, CompactStr)]) -> Result<T, Error> {
 		let url = format!(
 			"{}{}?api_key={}&language={}&{}",
 			BASE_URL,
 			path,
 			self.api_key,
 			self.language,
-			args.iter().map(|(k, v)| SmartString::from(*k) + "=" + v).join("&")
+			args.iter().map(|(k, v)| compact_str_url(k, v)).join("&")
 		);
 		dbg!(&url);
 		self.http.get(url).send().await?.json().await
 	}
 
-	pub async fn movie_search(&self, title: &str, year: Option<u64>) -> Result<MovieSearchResult, Error> {
+	pub async fn movie_search(&self, title: &str, year: Option<u16>) -> Result<MovieSearchResult, Error> {
 		let mut args = Vec::with_capacity(3);
 		args.push(("query", title.into()));
 		if let Some(year) = year {
@@ -55,7 +62,7 @@ impl Client {
 		self.get("/search/movie", &args).await
 	}
 
-	pub async fn movie_by_id(&self, id: u64, include_videos: bool, include_credits: bool) -> Result<Movie, Error> {
+	pub async fn movie_by_id(&self, id: u32, include_videos: bool, include_credits: bool) -> Result<Movie, Error> {
 		let args = match (include_videos, include_credits) {
 			(false, false) => None,
 			(true, false) => Some(("append_to_response", "videos".into())),
@@ -65,7 +72,7 @@ impl Client {
 		self.get(&format!("/movie/{}", id), args.as_ref().map(core::slice::from_ref).unwrap_or_default()).await
 	}
 
-	pub async fn movie_by_imdb_id(&self, id: u64) -> Result<Movie, Error> {
+	pub async fn movie_by_imdb_id(&self, id: u32) -> Result<Movie, Error> {
 		let result: FindResult = self.get(&format!("/find/tt{:07}", id), &[
 			("external_source", "imdb_id".into()),
 			("append_to_response", "images".into())
@@ -73,7 +80,7 @@ impl Client {
 		self.movie_by_id(result.movie_results[0].id, false, false).await
 	}
 
-	pub async fn tv_search(&self, title: &str, year: Option<u64>) -> Result<TVSearchResult, Error> {
+	pub async fn tv_search(&self, title: &str, year: Option<u16>) -> Result<TVSearchResult, Error> {
 		let mut args = Vec::with_capacity(3);
 		args.push(("query", title.into()));
 		if let Some(year) = year {
@@ -83,7 +90,7 @@ impl Client {
 		self.get("/search/tv", &args).await
 	}
 
-	pub async fn tv_by_id(&self, id: u64, include_videos: bool, include_credits: bool) -> Result<TV, Error> {
+	pub async fn tv_by_id(&self, id: u32, include_videos: bool, include_credits: bool) -> Result<TV, Error> {
 		let args = match (include_videos, include_credits) {
 			(false, false) => None,
 			(true, false) => Some(("append_to_response", "videos".into())),
@@ -93,7 +100,7 @@ impl Client {
 		self.get(&format!("/tv/{}", id), args.as_ref().map(core::slice::from_ref).unwrap_or_default()).await
 	}
 
-	pub async fn tv_by_imdb_id(&self, id: u64) -> Result<TV, Error> {
+	pub async fn tv_by_imdb_id(&self, id: u32) -> Result<TV, Error> {
 		let result: FindResult = self.get(&format!("/find/tt{}", id), &[
 			("external_source", "imdb_id".into()),
 			("append_to_response", "images".into())
