@@ -1,9 +1,9 @@
+use compact_str::CompactStr;
 use serde::{Deserialize, Serialize};
-use smartstring::alias::String as SmartString;
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct Genre {
-	pub id: u64,
+	pub id: u16,
 	pub name: String,
 }
 
@@ -26,8 +26,8 @@ pub struct Video {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct Cast {
-	pub id: u64,
-	pub cast_id: u64,
+	pub id: u32,
+	pub cast_id: u32,
 	pub credit_id: String,
 	pub character: String,
 	pub gender: Option<u8>,
@@ -38,7 +38,7 @@ pub struct Cast {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct TVCast {
-	pub id: u64,
+	pub id: u32,
 	pub credit_id: String,
 	pub character: String,
 	pub gender: Option<u8>,
@@ -49,7 +49,7 @@ pub struct TVCast {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct TVCreator {
-	pub id: u64,
+	pub id: u32,
 	pub credit_id: String,
 	pub name: String,
 	pub gender: Option<u8>,
@@ -61,7 +61,7 @@ pub struct Crew {
 	pub credit_id: String,
 	pub department: String,
 	pub gender: Option<u8>,
-	pub id: u64,
+	pub id: u32,
 	pub job: String,
 	pub name: String,
 	pub profile_path: Option<String>,
@@ -83,7 +83,7 @@ pub struct TVCredits {
 pub struct LastEpisode {
 	pub air_date: String,
 	pub episode_number: u32,
-	pub id: u64,
+	pub id: u32,
 	pub name: String,
 	pub overview: String,
 	pub production_code: Option<String>,
@@ -95,7 +95,7 @@ pub struct LastEpisode {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct ProductionCompany {
-	pub id: u64,
+	pub id: u32,
 	pub logo_path: Option<String>,
 	pub name: String,
 	pub origin_country: String,
@@ -103,7 +103,7 @@ pub struct ProductionCompany {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct Network {
-	pub id: u64,
+	pub id: u32,
 	pub logo_path: Option<String>,
 	pub name: String,
 	pub origin_country: String,
@@ -113,7 +113,7 @@ pub struct Network {
 pub struct Season {
 	pub air_date: Option<String>,
 	pub episode_count: u32,
-	pub id: u64,
+	pub id: u32,
 	pub name: String,
 	pub overview: String,
 	pub poster_path: Option<String>,
@@ -122,7 +122,7 @@ pub struct Season {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct Movie {
-	pub id: u64,
+	pub id: u32,
 	pub imdb_id: String,
 	pub title: String,
 	pub tagline: String,
@@ -144,10 +144,10 @@ pub struct Movie {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct TV {
-	pub id: u64,
+	pub id: u32,
 	pub backdrop_path: Option<String>,
 	pub created_by: Vec<TVCreator>,
-	pub episode_run_time: Vec<u64>,
+	pub episode_run_time: Vec<u16>,
 	pub first_air_date: String,
 	pub genres: Vec<Genre>,
 	pub homepage: Option<String>,
@@ -177,7 +177,7 @@ pub struct TV {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct SearchMovie {
-	pub id: u64,
+	pub id: u32,
 	pub title: String,
 	pub original_title: String,
 	pub original_language: String,
@@ -192,7 +192,7 @@ pub struct SearchMovie {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct SearchTV {
-	pub id: u64,
+	pub id: u32,
 	pub name: String,
 	pub original_name: String,
 	pub original_language: String,
@@ -208,7 +208,7 @@ pub struct SearchTV {
 
 	#[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct FindMovie {
-	pub id: u64,
+	pub id: u32,
 	pub title: String,
 	pub original_title: String,
 	pub original_language: String,
@@ -222,7 +222,7 @@ pub struct FindMovie {
 
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct FindTV {
-	pub id: u64,
+	pub id: u32,
 	pub name: String,
 	pub original_name: String,
 	pub original_language: String,
@@ -261,12 +261,12 @@ pub struct FindResult {
 #[derive(Debug, PartialEq, Deserialize, Serialize)]
 pub struct TVExternalIds {
 	pub id: u32,
-	pub imdb_id: Option<SmartString>,
-	pub freebase_mid: Option<SmartString>,
-	pub freebase_id: Option<SmartString>,
+	pub imdb_id: Option<CompactStr>,
+	pub freebase_mid: Option<CompactStr>,
+	pub freebase_id: Option<CompactStr>,
 	pub tvdb_id: Option<u32>,
 	pub tvrage_id: Option<u32>,
-	pub facebook_id: Option<SmartString>,
-	pub instagram_id: Option<SmartString>,
-	pub twitter_id: Option<SmartString>
+	pub facebook_id: Option<CompactStr>,
+	pub instagram_id: Option<CompactStr>,
+	pub twitter_id: Option<CompactStr>
 }
